pyreco package
==============

Submodules
----------

pyreco.cross\_validation module
-------------------------------

.. automodule:: pyreco.cross_validation
   :members:
   :undoc-members:
   :show-inheritance:

pyreco.custom\_models module
----------------------------

.. automodule:: pyreco.custom_models
   :members:
   :undoc-members:
   :show-inheritance:

pyreco.layers module
--------------------

.. automodule:: pyreco.layers
   :members:
   :undoc-members:
   :show-inheritance:

pyreco.metrics module
---------------------

.. automodule:: pyreco.metrics
   :members:
   :undoc-members:
   :show-inheritance:

pyreco.models module
--------------------

.. automodule:: pyreco.models
   :members:
   :undoc-members:
   :show-inheritance:

pyreco.network\_prop\_extractor module
--------------------------------------

.. automodule:: pyreco.network_prop_extractor
   :members:
   :undoc-members:
   :show-inheritance:

pyreco.optimizers module
------------------------

.. automodule:: pyreco.optimizers
   :members:
   :undoc-members:
   :show-inheritance:

pyreco.plotting module
----------------------

.. automodule:: pyreco.plotting
   :members:
   :undoc-members:
   :show-inheritance:

pyreco.remove\_transients module
--------------------------------

.. automodule:: pyreco.remove_transients
   :members:
   :undoc-members:
   :show-inheritance:

pyreco.utils\_data module
-------------------------

.. automodule:: pyreco.utils_data
   :members:
   :undoc-members:
   :show-inheritance:

pyreco.utils\_networks module
-----------------------------

.. automodule:: pyreco.utils_networks
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pyreco
   :members:
   :undoc-members:
   :show-inheritance:
